Welcome
http://www.businessinsider.com/airbnb-a-13-billion-dollar-startups-first-ever-pitch-deck-2011-9
AirBed&Breakfast
Book rooms with locals, rather than hotels.
This is a PowerPoint reproduction of an early AirBnB pitch deck via Business Insider @

---

Problem
or become a host.
No easy way exists to book a room with a local
and its culture.
Hotels leave you disconnected from the city
booking travel online.
Price is an important concern for customers
Template by PitchDeckCoach.com

---

Solution
space to host travelers to:
A web platform where users can rent out their
MONEY
when traveling
SAVE
MONEY
MAKE
when hosting
local connection to the city
CULTURE
SHARE
Template by PitchDeckCoach.com

---
*Conversion confidence: 56% (12 pages)*
- ⚠ 9 pages could not be recovered. Install pdfmux[ocr] for better results.
- ⚠ 9 pages appear to have no extractable text